changeset 25577:8a541d5c62c0

(timezone-parse-date): Use < 69 not < 70 to distinguish 20YY from 19YY.
author Richard M. Stallman <rms@gnu.org>
date Mon, 06 Sep 1999 22:15:43 +0000
parents 913fac3ab440
children 4c9cf2c63703
files lisp/timezone.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/timezone.el	Mon Sep 06 22:15:10 1999 +0000
+++ b/lisp/timezone.el	Mon Sep 06 22:15:43 1999 +0000
@@ -196,12 +196,12 @@
 	  )
     (when year
       (setq year (match-string year date))
       ;; Guess ambiguous years.  Assume years < 70 don't predate the
       ;; Unix Epoch, so are 2000+.  Three-digit years -- do they ever
       ;; occur? -- are (arbitrarily) assumed to be 21st century.
       (if (< (length year) 4)
 	  (let ((y (string-to-int year)))
-	    (if (< y 70)
+	    (if (< y 69)
 		(setq y (+ y 100)))
 	    (setq year (int-to-string (+ 1900 y)))))
       (setq month
@@ -196,12 +196,12 @@
     (when year
       (setq year (match-string year date))
-      ;; Guess ambiguous years.  Assume years < 70 don't predate the
+      ;; Guess ambiguous years.  Assume years < 69 don't predate the
       ;; Unix Epoch, so are 2000+.  Three-digit years -- do they ever
       ;; occur? -- are (arbitrarily) assumed to be 21st century.